CREATE TABLE BlzBicDaten
(
    bic varchar(11)
    ,blz varchar(8)
    ,blzneu varchar(8)
    ,bezeichnung varchar(58)
    ,kurzbezeichnung varchar(40)
    ,pruefverfahren varchar(2)
    ,loeschkennzeichen varchar(1)
    ,aenderungskennzeichen varchar(1)
    ,ibanregel varchar(6)
);
CREATE TABLE Status
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,name varchar(100)
   ,deleted boolean
   ,modificationTime timestamp
);

CREATE TABLE Gruppe
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,name varchar(100)
   ,deleted boolean
   ,modificationTime timestamp
);

CREATE TABLE Funktion
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,name varchar(100)
   ,deleted boolean
   ,modificationTime timestamp
);

CREATE TABLE MITGLIED
(
   ID varchar(36) PRIMARY KEY NOT NULL,
   VORNAME varchar(100),
   NACHNAME varchar(100),
   geburtsort varchar(100),
   GEBURTSDATUM timestamp,
   verstorbenAm timestamp,
   hochzeitsdatum timestamp,
   eintrittsdatum timestamp,
   austrittsdatum timestamp,
   uebernahme timestamp,
   klasseB timestamp,
   klasseBE timestamp,
   klasseC timestamp,
   klasseC1 timestamp,
   klasseCE timestamp,
   STRASSE varchar(200),
   PLZ varchar(10),
   ORT varchar(100),
   telefon varchar(50),
   mobiltelefon varchar(50),
   telefonDienstlich varchar(50),
   fax varchar(50),
   faxDienstlich varchar(50),
   email varchar(200),
   mitgliedsnummer varchar(10),
   geraetenummer varchar(10),
   beruf varchar(100),
   zusatzadresse varchar(100),
   kommentar varchar(1000),
   geschlecht int4,
   familienstand int4
   ,deleted boolean
   ,modificationTime timestamp
   ,status_id varchar(36)
   ,gruppe_id varchar(36)
   ,funktion1_id varchar(36)
   ,funktion2_id varchar(36)
   ,letzteWahlFunktion1 timestamp
   ,letzteWahlFunktion2 timestamp
);
ALTER TABLE Mitglied
ADD CONSTRAINT Mitglied_Status
FOREIGN KEY (status_id)
REFERENCES Status(id);
ALTER TABLE Mitglied
ADD CONSTRAINT Mitglied_Gruppe
FOREIGN KEY (gruppe_id)
REFERENCES Gruppe(id);
ALTER TABLE Mitglied
ADD CONSTRAINT Mitglied_Funktion_1
FOREIGN KEY (funktion1_id)
REFERENCES Funktion(id);
ALTER TABLE Mitglied
ADD CONSTRAINT Mitglied_Funktion_2
FOREIGN KEY (funktion2_id)
REFERENCES Funktion(id);

CREATE TABLE MITGLIEDSERWEITERUNG
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,MITGLIED_ID varchar(36)
   ,deleted boolean
   ,modificationTime timestamp
   ,discriminator varchar(100)
);
ALTER TABLE MITGLIEDSERWEITERUNG
ADD CONSTRAINT MITGLIEDSERWEITERUNG_MITGLIED_0
FOREIGN KEY (MITGLIED_ID)
REFERENCES MITGLIED(ID);

create table BeitragsArt 
(
    id varchar(36) PRIMARY KEY NOT NULL
    ,beitragsart varchar(100)
    ,betrag float8
    ,modificationTime timestamp
    ,deleted boolean
);

create table DebitNote
(
    id varchar(36) PRIMARY KEY NOT NULL
    ,name varchar(100)
    ,number varchar(10)
    ,bankCode varchar(8)
    ,bankName varchar(100)
    ,accountOwner varchar(100)
    ,active boolean
    ,iban varchar(34)
    ,bic varchar(11)
    ,designatedUse varchar(100)
    ,prenotificationNeeded boolean
    ,mandateid varchar(35)
    ,dateOfSignature timestamp
    ,lastUsed timestamp
    ,firstUse boolean
    ,ultimateDebitor varchar(100)
    
);

create table PaymentHistoryValue
(
    id varchar(36) PRIMARY KEY NOT NULL
    ,amount float8
    ,debitNote_id varchar(36)
    ,currentDebitNote_id varchar(36)
    ,creationDate timestamp
    ,modificationUser_id varchar(36)
);
ALTER TABLE PaymentHistoryValue
    ADD CONSTRAINT PaymentHistoryValue_DebitNote_0
    FOREIGN KEY (debitNote_id)
    REFERENCES DebitNote(id);
ALTER TABLE PaymentHistoryValue
    ADD CONSTRAINT PaymentHistoryValue_DebitNote_1
    FOREIGN KEY (currentDebitNote_id)
    REFERENCES DebitNote(id);
ALTER TABLE PaymentHistoryValue
    ADD CONSTRAINT PaymentHistoryValue_User_0
    FOREIGN KEY (modificationUser_id)
    REFERENCES auth_User(id);

CREATE TABLE BeitragsErweiterung
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,zahlweise int4
   ,individualBeitrag float8
   ,beitragsart_id varchar(36)
   ,lastschrift_id varchar(36)
   ,erstinfoneeded boolean
);
ALTER TABLE BeitragsErweiterung
ADD CONSTRAINT BeitragsErweiterung_Mitgliedserweiterung_0
FOREIGN KEY (ID)
REFERENCES MITGLIEDSERWEITERUNG(ID);
ALTER TABLE BeitragsErweiterung
ADD CONSTRAINT BeitragsErweiterung_BeitragsArt
FOREIGN KEY (BeitragsArt_id)
REFERENCES BeitragsArt(ID);
ALTER TABLE BeitragsErweiterung
ADD CONSTRAINT BeitragsErweiterung_DebitNote
FOREIGN KEY (lastschrift_id)
REFERENCES DebitNote(ID);

CREATE TABLE Rule
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,parent_id varchar(36)
   ,discriminator varchar(100)
);

ALTER TABLE Rule
ADD CONSTRAINT Rule_Rule
FOREIGN KEY (parent_id)
REFERENCES Rule(id);

CREATE TABLE AndRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
);
ALTER TABLE AndRule
ADD CONSTRAINT AndRule_Rule
FOREIGN KEY (id)
REFERENCES Rule(id);

CREATE TABLE OrRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
);
ALTER TABLE OrRule
ADD CONSTRAINT OrRule_Rule
FOREIGN KEY (id)
REFERENCES Rule(id);

CREATE TABLE NotRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
);
ALTER TABLE NotRule
ADD CONSTRAINT NotRule_Rule
FOREIGN KEY (id)
REFERENCES Rule(id);

CREATE TABLE DateRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
   , minage int4
   , maxage int4
);
ALTER TABLE DateRule
ADD CONSTRAINT DateRule_Rule
FOREIGN KEY (id)
REFERENCES Rule(id);


CREATE TABLE AgeRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
   , minage int4
);
ALTER TABLE AgeRule
ADD CONSTRAINT AgeRule_Rule
FOREIGN KEY (id)
REFERENCES Rule(id);

CREATE TABLE Lehrgang
(
   ID varchar(36) PRIMARY KEY NOT NULL
   , name varchar(100)
   , rule_id varchar(36)
   ,deleted boolean
   ,modificationTime timestamp
   ,gruppen varchar(100)
);

ALTER TABLE Lehrgang
ADD CONSTRAINT Lehrgang_Rule
FOREIGN KEY (rule_id)
REFERENCES Rule(id);

CREATE TABLE Dienstgrad
(
   ID varchar(36) PRIMARY KEY NOT NULL
   , name varchar(100)
   , rule_id varchar(36)
   ,deleted boolean
   ,modificationTime timestamp
);

ALTER TABLE Dienstgrad
ADD CONSTRAINT Dienstgrad_Rule
FOREIGN KEY (rule_id)
REFERENCES Rule(id);

CREATE TABLE LehrgangsErweiterung
(
   ID varchar(36) PRIMARY KEY NOT NULL
);
ALTER TABLE LehrgangsErweiterung
ADD CONSTRAINT LehrgangsErweiterung_Mitgliedserweiterung_0
FOREIGN KEY (ID)
REFERENCES MITGLIEDSERWEITERUNG(ID);

CREATE TABLE DienstgradErweiterung
(
   ID varchar(36) PRIMARY KEY NOT NULL
);
ALTER TABLE DienstgradErweiterung
ADD CONSTRAINT DienstgradErweiterung_Mitgliedserweiterung_0
FOREIGN KEY (ID)
REFERENCES MITGLIEDSERWEITERUNG(ID);

CREATE TABLE LehrgangsTeilnahme
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,deleted boolean
   ,modificationTime timestamp
   ,lehrgang_id varchar(36)
   ,erweiterung_id varchar(36)
   ,datum timestamp
   ,note float8
   ,bestanden boolean
);
ALTER TABLE LehrgangsTeilnahme
ADD CONSTRAINT LehrgangsTeilnahme_Lehrgang
FOREIGN KEY (Lehrgang_id)
REFERENCES Lehrgang(id);
ALTER TABLE LehrgangsTeilnahme
ADD CONSTRAINT LehrgangsTeilnahme_LehrgangsErweiterung
FOREIGN KEY (erweiterung_id)
REFERENCES lehrgangserweiterung(id);

CREATE TABLE DienstgradVerleihung
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,deleted boolean
   ,modificationTime timestamp
   ,dienstgrad_id varchar(36)
   ,erweiterung_id varchar(36)
   ,datum timestamp
);
ALTER TABLE DienstgradVerleihung
ADD CONSTRAINT DienstgradVerleihung_Lehrgang
FOREIGN KEY (Dienstgrad_id)
REFERENCES Dienstgrad(id);
ALTER TABLE DienstgradVerleihung
ADD CONSTRAINT DienstgradVerleihung_DienstgradErweiterung
FOREIGN KEY (erweiterung_id)
REFERENCES DienstgradErweiterung(id);

CREATE TABLE FuehrerscheinRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,fuehrerschein varchar(10)
);
ALTER TABLE FuehrerscheinRule
ADD CONSTRAINT FuehrerscheinRule_Rule
FOREIGN KEY (id)
REFERENCES Rule(id);

CREATE TABLE LehrgangsTeilnahmeRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
   , lehrgang_id varchar(36)
   ,bestanden boolean
);
ALTER TABLE LehrgangsTeilnahmeRule
ADD CONSTRAINT LehrgangsTeilnahmeRule_Rule
FOREIGN KEY (id)
REFERENCES DateRule(id);
ALTER TABLE LehrgangsTeilnahmeRule
ADD CONSTRAINT LehrgangsTeilnahmeRule_Lehrgang
FOREIGN KEY (lehrgang_id)
REFERENCES Lehrgang(id);

CREATE TABLE LehrgangsgruppenRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
   , gruppe varchar(100)
   , minCount int4
);
ALTER TABLE LehrgangsgruppenRule
ADD CONSTRAINT LehrgangsgruppenRule_Rule
FOREIGN KEY (id)
REFERENCES Rule(id);

CREATE TABLE DienstgradRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
   , dienstgrad_id varchar(36)
   , erhalten boolean
);
ALTER TABLE DienstgradRule
ADD CONSTRAINT DienstgradRule_Rule
FOREIGN KEY (id)
REFERENCES DateRule(id);
ALTER TABLE DienstgradRule
ADD CONSTRAINT DienstgradRule_Dienstgrad
FOREIGN KEY (dienstgrad_id)
REFERENCES Dienstgrad(id);

CREATE TABLE StatusRule
(
   ID varchar(36) PRIMARY KEY NOT NULL
   , status_id varchar(36)
);
ALTER TABLE StatusRule
ADD CONSTRAINT StatusRule_Rule
FOREIGN KEY (id)
REFERENCES Rule(id);
ALTER TABLE StatusRule
ADD CONSTRAINT StatusRule_Status
FOREIGN KEY (status_id)
REFERENCES Status(id);

CREATE TABLE Dienstart
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,name varchar(100)
   ,deleted boolean
   ,modificationTime timestamp
);

CREATE TABLE Zielgruppe
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,name varchar(100)
   ,deleted boolean
   ,modificationTime timestamp
);

CREATE TABLE Geraet
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,bezeichnung varchar(50)
   ,typ varchar(50)
   ,groesse varchar(50)
   ,hersteller varchar(50)
   ,lieferant varchar(50)
   ,ablageort varchar(50)
   ,seriennummer varchar(30)
   ,inventarnummer varchar(30)
   ,preis float8
   ,monatlich float8
   ,menge varchar(10)
   ,ausgabedatum timestamp
   ,herstellungsdatum timestamp
   ,ausmusterung timestamp
   ,beschaffung timestamp
   ,lebensdauer int4
   ,kommentar varchar(5000)
   ,mitglied_id varchar(36)
   ,deleted boolean
   ,modificationTime timestamp
);
ALTER TABLE Geraet
ADD CONSTRAINT Geraet_Mitglied
FOREIGN KEY (mitglied_id)
REFERENCES Mitglied(id);

CREATE TABLE Dienst
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,dienstart_id varchar(36)
   ,datum timestamp
   ,beginn float8
   ,alarm float8
   ,ende float8
   ,sonstigesGeraet varchar(200)
   ,ablauf varchar(1000)
   ,leitung varchar(50)
   ,zielgruppe_id varchar(36) 
   ,deleted boolean
   ,modificationTime timestamp
);
ALTER TABLE Dienst
ADD CONSTRAINT Dienst_Dienstart
FOREIGN KEY (dienstart_id)
REFERENCES Dienstart(id);
ALTER TABLE Dienst
ADD CONSTRAINT Dienst_Zielgruppe
FOREIGN KEY (zielgruppe_id)
REFERENCES Zielgruppe(id);

CREATE TABLE Dienst_Teilnehmer
(
    dienst_id varchar(36)
    ,mitglied_id varchar(36)
);
ALTER TABLE Dienst_Teilnehmer
ADD CONSTRAINT Dienst_Teilnehmer_1
FOREIGN KEY (dienst_id)
REFERENCES Dienst(id);
ALTER TABLE Dienst_Teilnehmer
ADD CONSTRAINT Dienst_Teilnehmer_2
FOREIGN KEY (mitglied_id)
REFERENCES Mitglied(id);


CREATE TABLE Dienst_Geraete
(
    dienst_id varchar(36)
    ,geraet_id varchar(36)
);
ALTER TABLE Dienst_Geraete
ADD CONSTRAINT Dienst_Geraete_1
FOREIGN KEY (dienst_id)
REFERENCES Dienst(id);
ALTER TABLE Dienst_Geraete
ADD CONSTRAINT Dienst_Geraete_2
FOREIGN KEY (geraet_id)
REFERENCES Geraet(id);

CREATE TABLE DIENSTERWEITERUNG
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,dienst_ID varchar(36)
   ,deleted boolean
   ,modificationTime timestamp
   ,discriminator varchar(100)
);
ALTER TABLE DIENSTERWEITERUNG
ADD CONSTRAINT DIENSTERWEITERUNG_DIENST_0
FOREIGN KEY (DIENST_ID)
REFERENCES DIENST(ID);

CREATE TABLE PruefungsTyp
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,name varchar(50)
   ,beschreibung varchar(500)
   ,pruefungsinterval int4
   ,deleted boolean
   ,modificationTime timestamp
);
CREATE TABLE GeraeteErweiterung
(
   ID varchar(36) PRIMARY KEY NOT NULL
   ,geraet_ID varchar(36)
   ,deleted boolean
   ,modificationTime timestamp
   ,discriminator varchar(100)
);
ALTER TABLE GeraeteErweiterung
ADD CONSTRAINT GeraeteErweiterung_Geraet_0
FOREIGN KEY (Geraet_ID)
REFERENCES Geraet(ID);

CREATE TABLE PruefungsErweiterung
(
   ID varchar(36) PRIMARY KEY NOT NULL
);
ALTER TABLE PruefungsErweiterung
ADD CONSTRAINT PruefungsErweiterung_GeraeteErweiterung_0
FOREIGN KEY (ID)
REFERENCES GeraeteErweiterung(ID);

CREATE TABLE Pruefung
(
    ID varchar(36) PRIMARY KEY NOT NULL
    ,pruefungsErweiterung_ID varchar(36)
    ,pruefungsTyp_ID varchar(36)
    ,resultat int4
    ,termin timestamp
    ,kommentar varchar(1000)
    ,kosten float8
    ,deleted boolean
    ,modificationTime timestamp
);
ALTER TABLE Pruefung
ADD CONSTRAINT Pruefung_PruefungsErweiterung_0
FOREIGN KEY (pruefungsErweiterung_id)
REFERENCES PruefungsErweiterung(ID);

CREATE TABLE Geraet_PruefungsTyp
(
    geraet_id varchar(36)
    ,pruefungstyp_id varchar(36)
);
ALTER TABLE Geraet_PruefungsTyp
ADD CONSTRAINT Geraet_PruefungsTyp_0
FOREIGN KEY (pruefungsTyp_id)
REFERENCES PruefungsTyp(ID);
ALTER TABLE Geraet_PruefungsTyp
ADD CONSTRAINT Geraet_PruefungsTyp_1
FOREIGN KEY (geraet_id)
REFERENCES geraet(ID);

CREATE TABLE Verein
(
    id varchar(36) PRIMARY KEY NOT NULL
    ,name varchar(200)
    ,homepage varchar(200)
    ,vorsitzender_id varchar(36)
    ,schriftfuehrer_id varchar(36)
    ,account_id varchar(36)
    ,glaeubigerID varchar(20)
    ,buchungsdatum varchar(20)
    ,authenticationContext_id varchar(36)
    ,deleted boolean
    ,modificationTime timestamp
);
ALTER TABLE Verein
ADD CONSTRAINT Verein_Mitglied_1
FOREIGN KEY (vorsitzender_id)
REFERENCES mitglied(ID);
ALTER TABLE Verein
ADD CONSTRAINT Verein_Mitglied_2
FOREIGN KEY (schriftfuehrer_id)
REFERENCES mitglied(ID);
ALTER TABLE Verein
ADD CONSTRAINT Verein_Account_1
FOREIGN KEY (account_id)
REFERENCES DebitNote(ID);
ALTER TABLE Verein
ADD CONSTRAINT Verein_AuthenticationContext_1
FOREIGN KEY (authenticationContext_id)
REFERENCES auth_AuthenticationContext(ID);

CREATE TABLE Inventur
(
    id varchar(36) PRIMARY KEY NOT NULL
    ,kommentar varchar(200)
    ,datum timestamp
    ,abgeschlossen boolean
    ,deleted boolean
    ,modificationTime timestamp
);

CREATE TABLE InventurItem
(
    id varchar(36) PRIMARY KEY NOT NULL
    ,inventur_id varchar(36)
    ,geraet_id varchar(36)
    ,status int4
    ,deleted boolean
    ,modificationTime timestamp
);

ALTER TABLE InventurItem
ADD CONSTRAINT InventurItem_Geraet_1
FOREIGN KEY (geraet_id)
REFERENCES Geraet(ID);
ALTER TABLE InventurItem
ADD CONSTRAINT InventurItem_Inventur_1
FOREIGN KEY (inventur_id)
REFERENCES Inventur(ID);

CREATE TABLE FunctionHistoryEntry
(
    id varchar(36) PRIMARY KEY NOT NULL
    ,funktion_id varchar(36)
    ,mitglied_id varchar(36)
    ,start timestamp
    ,ende timestamp
    ,deleted boolean
    ,modificationTime timestamp
);
ALTER TABLE FunctionHistoryEntry
ADD CONSTRAINT FunctionHistoryEntry_Mitglied_1
FOREIGN KEY (mitglied_id)
REFERENCES Mitglied(ID);
ALTER TABLE FunctionHistoryEntry
ADD CONSTRAINT FunctionHistoryEntry_Funktion_1
FOREIGN KEY (funktion_id)
REFERENCES Funktion(ID);

CREATE TABLE ExcludeList
(
    id varchar(36) PRIMARY KEY NOT NULL
    ,type varchar(36)
    ,deleted boolean
    ,modificationTime timestamp
);
CREATE TABLE ExcludeList_Mitglieder
(
    mitglied_id varchar(36)
    ,excludelist_id varchar(36)
);
ALTER TABLE ExcludeList_Mitglieder
ADD CONSTRAINT ExcludeList_Mitglieder_1
FOREIGN KEY (mitglied_id)
REFERENCES Mitglied(ID);
ALTER TABLE ExcludeList_Mitglieder
ADD CONSTRAINT ExcludeList_Mitglieder_2
FOREIGN KEY (excludelist_id)
REFERENCES ExcludeList(ID);
